<template>
  <div class="app-container page">
    <div class="form-card">
      <el-form :model="queryParams" ref="queryRef" :inline="true" v-show="showSearch" label-width="80px">
        <el-form-item label="名称" prop="holidayName">
          <el-input
            v-model="queryParams.holidayName"
            placeholder="请输入节假日名称"
            clearable
            style="width: 240px"
            @keyup.enter="handleQuery"
          />
        </el-form-item>
        <el-form-item label="日期" prop="holidayDate">
          <el-date-picker
            v-model="queryParams.holidayDate"
            type="date"
            placeholder="选择节假日日期"
            value-format="YYYY-MM-DD"
            style="width: 240px"
          />
        </el-form-item>
        <el-form-item label="类型" prop="holidayType">
          <el-select v-model="queryParams.holidayType" placeholder="节假日类型" clearable style="width: 240px">
            <el-option
              v-for="dict in sys_holiday_type"
              :key="dict.value"
              :label="dict.label"
              :value="dict.value"
            />
          </el-select>
        </el-form-item>
        <el-form-item label="状态" prop="status">
          <el-select v-model="queryParams.status" placeholder="节假日状态" clearable style="width: 240px">
            <el-option
              v-for="dict in sys_normal_disable"
              :key="dict.value"
              :label="dict.label"
              :value="dict.value"
            />
          </el-select>
        </el-form-item>
        <el-form-item>
          <el-button type="primary" icon="Search" @click="handleQuery">搜索</el-button>
          <el-button icon="Refresh" @click="resetQuery">重置</el-button>
        </el-form-item>
      </el-form>
    </div>

    <div class="table-bg-style">
      <div class="table-box" style="margin-top: 0">
        <el-row :gutter="10" class="mb8" style="margin-top: 8px">
          <el-col :span="1.5">
            <el-button type="primary" plain icon="Plus" @click="handleAdd" v-hasPermi="['system:holiday:add']"
              >新增</el-button
            >
          </el-col>
          <el-col :span="1.5">
            <el-button
              type="success"
              plain
              icon="Edit"
              :disabled="single"
              @click="handleUpdate"
              v-hasPermi="['system:holiday:edit']"
              >修改</el-button
            >
          </el-col>
          <el-col :span="1.5">
            <el-button
              type="danger"
              plain
              icon="Delete"
              :disabled="multiple"
              @click="handleDelete"
              v-hasPermi="['system:holiday:remove']"
              >删除</el-button
            >
          </el-col>
          <el-col :span="1.5">
            <el-button type="warning" plain icon="Download" @click="handleExport" v-hasPermi="['system:holiday:export']"
              >导出</el-button
            >
          </el-col>
          <right-toolbar v-model:showSearch="showSearch" @queryTable="getList"></right-toolbar>
        </el-row>

        <el-table v-loading="loading" :data="holidayList" @selection-change="handleSelectionChange">
          <el-table-column type="selection" width="55" align="center" />
          <el-table-column label="节假日ID" align="center" prop="holidayId" />
          <el-table-column label="节假日名称" align="center" prop="holidayName" :show-overflow-tooltip="true" />
          <el-table-column label="节假日日期" align="center" prop="holidayDate" width="100" />
          <el-table-column label="节假日类型" align="center" prop="holidayType">
            <template #default="scope">
              <dict-tag :options="sys_holiday_type" :value="scope.row.holidayType" />
            </template>
          </el-table-column>
          <el-table-column label="状态" align="center" prop="status">
            <template #default="scope">
              <dict-tag :options="sys_normal_disable" :value="scope.row.status" />
            </template>
          </el-table-column>
          <el-table-column label="创建时间" align="center" prop="createTime" width="100">
            <template #default="scope">
              <span>{{ parseTime(scope.row.createTime) }}</span>
            </template>
          </el-table-column>
          <el-table-column label="操作" align="center" class-name="small-padding fixed-width">
            <template #default="scope">
              <el-button link type="primary" icon="Edit" @click="handleUpdate(scope.row)" v-hasPermi="['system:holiday:edit']">修改</el-button>
              <el-button link type="primary" icon="Delete" @click="handleDelete(scope.row)" v-hasPermi="['system:holiday:remove']">删除</el-button>
            </template>
          </el-table-column>
        </el-table>

        <pagination
          v-show="total > 0"
          :total="total"
          v-model:page="queryParams.pageNum"
          v-model:limit="queryParams.pageSize"
          @pagination="getList"
        />
      </div>
    </div>

    <!-- 添加或修改节假日对话框 -->
    <el-dialog :title="title" v-model="open" width="500px" append-to-body>
      <el-form ref="holidayRef" :model="form" :rules="rules" label-width="100px">
        <el-form-item label="节假日名称" prop="holidayName">
          <el-input v-model="form.holidayName" placeholder="请输入节假日名称" />
        </el-form-item>
        <el-form-item label="节假日日期" prop="holidayDate">
          <el-date-picker
            v-model="form.holidayDate"
            type="date"
            placeholder="选择节假日日期"
            value-format="YYYY-MM-DD"
            style="width: 100%"
          />
        </el-form-item>
        <el-form-item label="节假日类型" prop="holidayType">
          <el-select v-model="form.holidayType" placeholder="请选择节假日类型" style="width: 100%">
            <el-option
              v-for="dict in sys_holiday_type"
              :key="dict.value"
              :label="dict.label"
              :value="dict.value"
            />
          </el-select>
        </el-form-item>
        <el-form-item label="状态" prop="status">
          <el-radio-group v-model="form.status">
            <el-radio
              v-for="dict in sys_normal_disable"
              :key="dict.value"
              :label="dict.value"
            >{{ dict.label }}</el-radio>
          </el-radio-group>
        </el-form-item>
        <el-form-item label="备注" prop="remark">
          <el-input v-model="form.remark" type="textarea" placeholder="请输入内容" />
        </el-form-item>
      </el-form>
      <template #footer>
        <div class="dialog-footer">
          <el-button type="primary" @click="submitForm">确 定</el-button>
          <el-button @click="cancel">取 消</el-button>
        </div>
      </template>
    </el-dialog>
  </div>
</template>

<script setup>
import { listHoliday, getHoliday, delHoliday, addHoliday, updateHoliday, exportHoliday } from "@/api/system/holiday";

const { proxy } = getCurrentInstance();
const { sys_normal_disable } = proxy.useDict("sys_normal_disable");
const sys_holiday_type = ref([]);

// 初始化节假日类型字典
sys_holiday_type.value = [
  { value: "0", label: "正常假日" },
  { value: "1", label: "工作日调休" }
];

const holidayList = ref([]);
const open = ref(false);
const loading = ref(true);
const showSearch = ref(true);
const ids = ref([]);
const single = ref(true);
const multiple = ref(true);
const total = ref(0);
const title = ref("");

const data = reactive({
  form: {},
  queryParams: {
    pageNum: 1,
    pageSize: 10,
    holidayName: undefined,
    holidayDate: undefined,
    holidayType: undefined,
    status: undefined
  },
  rules: {
    holidayName: [
      { required: true, message: "节假日名称不能为空", trigger: "blur" }
    ],
    holidayDate: [
      { required: true, message: "节假日日期不能为空", trigger: "blur" }
    ],
    holidayType: [
      { required: true, message: "节假日类型不能为空", trigger: "change" }
    ],
    status: [
      { required: true, message: "状态不能为空", trigger: "change" }
    ]
  }
});

const { queryParams, form, rules } = toRefs(data);

/** 查询节假日列表 */
function getList() {
  loading.value = true;
  listHoliday(queryParams.value).then(response => {
    holidayList.value = response.rows;
    total.value = response.total;
    loading.value = false;
  });
}

// 取消按钮
function cancel() {
  open.value = false;
  reset();
}

// 表单重置
function reset() {
  form.value = {
    holidayId: undefined,
    holidayName: undefined,
    holidayDate: undefined,
    holidayType: "0",
    status: "0",
    remark: undefined
  };
  proxy.resetForm("holidayRef");
}

/** 搜索按钮操作 */
function handleQuery() {
  queryParams.value.pageNum = 1;
  getList();
}

/** 重置按钮操作 */
function resetQuery() {
  proxy.resetForm("queryRef");
  handleQuery();
}

/** 多选框选中数据 */
function handleSelectionChange(selection) {
  ids.value = selection.map(item => item.holidayId);
  single.value = selection.length != 1;
  multiple.value = !selection.length;
}

/** 新增按钮操作 */
function handleAdd() {
  reset();
  open.value = true;
  title.value = "添加节假日";
}

/** 修改按钮操作 */
function handleUpdate(row) {
  reset();
  const holidayId = row.holidayId || ids.value[0];
  getHoliday(holidayId).then(response => {
    form.value = response.data;
    open.value = true;
    title.value = "修改节假日";
  });
}

/** 提交按钮 */
function submitForm() {
  proxy.$refs["holidayRef"].validate(valid => {
    if (valid) {
      if (form.value.holidayId != undefined) {
        updateHoliday(form.value).then(response => {
          proxy.$modal.msgSuccess("修改成功");
          open.value = false;
          getList();
        });
      } else {
        addHoliday(form.value).then(response => {
          proxy.$modal.msgSuccess("新增成功");
          open.value = false;
          getList();
        });
      }
    }
  });
}

/** 删除按钮操作 */
function handleDelete(row) {
  const holidayIds = row.holidayId || ids.value;
  proxy.$modal.confirm('是否确认删除节假日编号为"' + holidayIds + '"的数据项?').then(function() {
    return delHoliday(holidayIds);
  }).then(() => {
    getList();
    proxy.$modal.msgSuccess("删除成功");
  }).catch(() => {});
}

/** 导出按钮操作 */
function handleExport() {
  proxy.download("system/holiday/export", {
    ...queryParams.value
  }, `holiday_${new Date().getTime()}.xlsx`);
}

getList();
</script>